<?php

namespace FiloBlu\DisableShop\Helper;

use FiloBlu\DisableShop\Model\Logger\Logger;
use Magento\Customer\Model\Session;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Http\Context;
use Magento\Store\Model\ScopeInterface;

/**
 *
 */
class Data extends AbstractHelper
{
    protected $_loggerDisableShop;
    protected $_httpContext;
    protected $_customerSession;

    /**
     * Data constructor.
     * @param \Magento\Framework\App\Helper\Context $context
     * @param Logger $logger
     * @param Context $httpContext
     * @param Session $customerSession
     */
    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        Logger $logger,
        Context $httpContext,
        Session $customerSession
    ) {
        $this->_loggerDisableShop = $logger;
        $this->_httpContext = $httpContext;
        $this->_customerSession = $customerSession;
        parent::__construct($context);
    }

    /**
     * @return false|mixed
     */
    public function canDisableShop()
    {
        if ($this->isCurrentUserExcluded($this->getExcludeCustomerGroupDisabledShop())) {
            return false;
        }

        return (bool)$this->getConfig('general/disable_shop');
    }

    /**
     * @param $customerGroupExcluded
     * @return bool
     */
    private function isCurrentUserExcluded($customerGroupExcluded)
    {
        $isLogged = $this->_httpContext->getValue(\Magento\Customer\Model\Context::CONTEXT_AUTH);
        $_currentCustomerGroupId = '-1';
        if ($isLogged) {
            $_currentCustomerGroupId = '-2,';
            $_currentCustomerGroupId .= $this->_customerSession->getCustomer()->getGroupId();
        }
        $_arrayCurrentCustomerGroupId = explode(',', $_currentCustomerGroupId ?? '');
        $_arrayCustomerGroupExcluded = explode(',', $customerGroupExcluded ?? '');
        return (count(array_intersect($_arrayCurrentCustomerGroupId, $_arrayCustomerGroupExcluded)) != 0);
    }

    private function getExcludeCustomerGroupDisabledShop()
    {
        return $this->getConfig('general/disable_shop_exclude_customer_group');
    }

    public function getConfig($config_path, $section = 'filoblu_disableshop_section')
    {
        return $this->scopeConfig->getValue(
            $section . '/' . $config_path,
            ScopeInterface::SCOPE_STORE
        );
    }

    public function canHidePrice()
    {
        return $this->isCurrentUserExcluded($this->getExcludeCustomerGroupHidePrice()) ? false : $this->getConfig(
            'general/hide_price'
        );
    }

    private function getExcludeCustomerGroupHidePrice()
    {
        return $this->getConfig('general/hide_price_exclude_customer_group');
    }

    /**
     * @return string
     */
    public function getCategoriesDisabledShop()
    {
        if ($this->isCurrentUserExcluded($this->getExcludeCustomerGroupDisabledShop())) {
            return '';
        }

        return (string)$this->getConfig('general/disable_shop_category');
    }

    /**
     * @return string
     */
    public function getCategoriesHidePrice()
    {
        if ($this->isCurrentUserExcluded($this->getExcludeCustomerGroupHidePrice())) {
            return '';
        }

        return (string)$this->getConfig('general/hide_price_category');
    }

    /**
     * @param $message
     * @return void
     */
    public function log($message)
    {
        if ($this->getConfig('debug/enable_log')) {
            $this->_loggerDisableShop->info($message);
        }
    }
}
