<?php

namespace FiloBlu\DisableShop\Observer;

use FiloBlu\DisableShop\Helper\Data;
use Magento\Framework\Event\Observer as EventObserver;
use Magento\Framework\Event\ObserverInterface;

/**
 *
 */
class CatalogProductCollectionLoadAfter implements ObserverInterface
{
    protected $helper;

    /**
     * CatalogProductCollectionLoadAfter constructor.
     * @param Data $helper
     */
    public function __construct(Data $helper)
    {
        $this->helper = $helper;
    }

    public function execute(EventObserver $observer)
    {
        $this->helper->log('### Catalog Product Collection Load After ###');

        $collection = $observer->getEvent()->getCollection();

        $canDisableShop = $this->helper->canDisableShop();
        $canHidePrice = $this->helper->canHidePrice();

        $this->helper->log('- Can disable shop -> ' . ($canDisableShop ? 'true' : 'false'));
        $this->helper->log('- Can hide price -> ' . ($canHidePrice ? 'true' : 'false'));

        $categoriesDisableShop = explode(',', $this->helper->getCategoriesDisabledShop());
        $categoriesHidePrice = explode(',', $this->helper->getCategoriesHidePrice());

        $this->helper->log('- Categories disable shop: ' . implode(',', $categoriesDisableShop));
        $this->helper->log('- Categories hide price shop: ' . implode(',', $categoriesHidePrice));

        foreach ($collection as $product) {
            $canDisableShopSingleProduct = ($canDisableShop ? true : $product->getDisableShop());

            if (!$canDisableShopSingleProduct) {
                $canDisableShopSingleProduct = (bool)count(
                    array_intersect($categoriesDisableShop, $product->getCategoryIds())
                );
            }

            if ($canDisableShopSingleProduct) {
                $product->setDisableAddToCart(true);
                $this->helper->log('- Can disable shop for product -> ' . $product->getSku());
            }

            $canHidePriceSingleProduct = ($canHidePrice ? true : $product->getHidePrice());

            if (!$canHidePriceSingleProduct) {
                $canHidePriceSingleProduct = (bool)count(
                    array_intersect($categoriesHidePrice, $product->getCategoryIds())
                );
            }

            if ($canHidePriceSingleProduct) {
                $product->setCanShowPrice(false);
                $this->helper->log('- Can hide price for product -> ' . $product->getSku());
            }
        }
    }
}
