<?php

namespace FiloBlu\DisableShop\Observer;

use FiloBlu\DisableShop\Helper\Data;
use Magento\Framework\Event\Observer as EventObserver;
use Magento\Framework\Event\ObserverInterface;

class CatalogProductLoadAfter implements ObserverInterface
{
    protected $_helper;

    public function __construct(Data $helper)
    {
        $this->_helper = $helper;
    }

    public function execute(EventObserver $observer)
    {
        $this->_helper->log('### Catalog Product Load After ###');

        $product = $observer->getEvent()->getProduct();

        $this->_helper->log('- Sku ' . $product->getSku());

        $canDisableShop = $this->_helper->canDisableShop();
        $canHidePrice = $this->_helper->canHidePrice();

        $this->_helper->log('- Can disable shop -> ' . ($canDisableShop ? 'true' : 'false'));
        $this->_helper->log('- Can hide price -> ' . ($canHidePrice ? 'true' : 'false'));

        $canDisableShopSingleProduct = ($canDisableShop ? true : $product->getDisableShop());

        if (!$canDisableShopSingleProduct) {
            $categoriesDisableShop = explode(',', $this->_helper->getCategoriesDisabledShop());
            $canDisableShopSingleProduct = (bool)count(
                array_intersect($categoriesDisableShop, $product->getCategoryIds())
            );
        }

        if ($canDisableShopSingleProduct) {
            $product->setDisableAddToCart(true);
            $this->_helper->log('- Can disable shop for product -> ' . $product->getSku());
        }

        $canHidePriceSingleProduct = ($canHidePrice ? true : $product->getHidePrice());

        if (!$canHidePriceSingleProduct) {
            $categoriesHidePrice = explode(',', $this->_helper->getCategoriesHidePrice());
            $canHidePriceSingleProduct = (bool)count(
                array_intersect($categoriesHidePrice, $product->getCategoryIds())
            );
        }

        if ($canHidePriceSingleProduct) {
            $product->setCanShowPrice(false);
            $this->_helper->log('- Can hide price for product -> ' . $product->getSku());
        }
    }
}
