<?php

namespace FiloBlu\DisableShop\Observer;

use FiloBlu\DisableShop\Helper\Data;
use Magento\Framework\Event\Observer as EventObserver;
use Magento\Framework\Event\ObserverInterface;
use Magento\Store\Model\StoreManagerInterface;

/**
 * Class ControllerActionPredispatch
 * @package FiloBlu\DisableShop\Observer
 */
class ControllerActionPredispatch implements ObserverInterface
{

    /**
     * @var Data
     */
    protected $_helper;
    /**
     * @var StoreManagerInterface
     */
    protected $_storeManager;

    /**
     * ControllerActionPredispatch constructor.
     * @param Data $helper
     * @param StoreManagerInterface $storeManager
     */
    public function __construct(
        Data $helper,
        StoreManagerInterface $storeManager
    ) {
        $this->_helper = $helper;
        $this->_storeManager = $storeManager;
    }

    /**
     * Apply is salable to product
     *
     * @param EventObserver $observer
     * @return $this
     */
    public function execute(EventObserver $observer)
    {
        $this->_helper->log('### Controller Action Predispatch ###');

        $request = $observer->getRequest();
        $_fullActionName = $request->getFullActionName();

        $this->_helper->log('- Full Action Name: ' . $_fullActionName);

        if ($this->_helper->canDisableShop()) {
            $_notAllowedFullActionNames = explode("\n", $this->_helper->getConfig('general/not_allowed_full_action_name'));
            $this->_helper->log('- Not Allowed Full Action Name: ' . implode(',', $_notAllowedFullActionNames));

            foreach ($_notAllowedFullActionNames as $_notAllowedFullActionName) {
                if ($_fullActionName == trim($_notAllowedFullActionName)) {
                    $this->_helper->log("- Match Found for {$_fullActionName}, redirect to " . $this->_storeManager->getStore()->getBaseUrl());
                    $response = $observer->getControllerAction()->getResponse();
                    $response->setRedirect($this->_storeManager->getStore()->getBaseUrl());
                } else {
                    $this->_helper->log("- No match for {$_fullActionName}");
                }
            }
        }

        return $this;
    }
}
